Index: src/runtime/runtime-debug.cc |
diff --git a/src/runtime/runtime-debug.cc b/src/runtime/runtime-debug.cc |
index 317ac8ecde5de0a764963734b5c71948d6f5c565..9cfe56b274237fe52e202550b5eba668ee662c3c 100644 |
--- a/src/runtime/runtime-debug.cc |
+++ b/src/runtime/runtime-debug.cc |
@@ -391,14 +391,13 @@ RUNTIME_FUNCTION(Runtime_DebugGetProperty) { |
return *DebugGetProperty(&it); |
} |
- |
-// Return the property type calculated from the property details. |
+// Return the property kind calculated from the property details. |
// args[0]: smi with property details. |
-RUNTIME_FUNCTION(Runtime_DebugPropertyTypeFromDetails) { |
+RUNTIME_FUNCTION(Runtime_DebugPropertyKindFromDetails) { |
SealHandleScope shs(isolate); |
DCHECK_EQ(1, args.length()); |
CONVERT_PROPERTY_DETAILS_CHECKED(details, 0); |
- return Smi::FromInt(static_cast<int>(details.type())); |
+ return Smi::FromInt(static_cast<int>(details.kind())); |
} |